@@ -1,4 +1,4 @@
-use sauron_core::prelude::*;
+use sauron::prelude::*;
 
 //#[test]
 //TODO: FIXME
